---
title: 사업자 양도양수시에는 어떤 절차가 필요한가요?
category: 자주 묻는 질문 (일반 문의) > 결제서비스 > 결제서비스
seo:
  title: 사업자 양도양수(변경) 절차
  description: >-
    사업자정보가 변경되는 경우 PG사와의 계약도 신규로 진행되어야 합니다. 포트원의 계정을 그대로 유지하고자 하시는 경우의 절차를
    설명드립니다.
  keywords:
    - 계약절차
tags:
  - 공통
  - 계약절차
pgCompanies:
  - 공통
searchTags:
  - 합병
  - 사업자정보변경
  - 사업자정보 변경
  - 사업자번호 변경
  - 사업자번호변경
  - 신규사업자
  - 인수
  - 사업자변경
  - 양도양수절차
  - 양도양수
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="사업자정보가 변경되는 경우 (사업자번호 변경) PG사와의 계약도 신규로 진행되어야 합니다.
포트원의 계정을 그대로 유지하고자 하시는 경우 다음의 절차로 진행하실 수 있습니다." title="" />

### **포트원 관리자콘솔 계정 유지**

<Callout content="기존 포트원 관리자콘솔 결제내역을 유지하시는 상태에서 신규 사업자의 결제내역을 함께 관리하실 수 있습니다." title="참고사항" icon="💡" />

1. **포트원 관리자콘솔 내 사업자정보 초기화**

- 포트원 관리자콘솔 내 등록된 사업자정보 초기화 합니다. \
  (신규 사업자로 재등록하기 위함)이를 위해 포트원으로 요청주시면 강제 초기화처리 해드리고 있습니다.\
  또한 현재 서비스 되고 있는 결제연동과 사업자정보 전환과는 관계가 없으니 우려하지 않으셔도 됩니다!

##### **2. 신규 사업자정보 재등록 & 신규PG신청**

- 포트원 관리자콘솔 내 신규 사업자정보 등록하신 후 신규계약절차와 동일하게 전자결제신청을 접수합니다.

<Callout title="전자결제 신청가이드 보러가기 ↗" icon="" />

##### **3. 신규 사업자로 PG사와 신규계약진행**

- 기존 사업자로 서비스 운영중에 신규 사업자로 신규계약을 동시에 진행합니다.
- 신규 사업자 심사를 받기 위한 사이트 내에는 신규사업자정보가 기입 되어있어야 하며, 카드사 심사를 받으실 상품페이지도 구현되어있어야 합니다.\
  (ex. 기존 서비스 유저들의 접근이 불가하도록 특정 계정으로만 로그인 가능하도록 처리)

##### **4. PG계약완료 후 상점정보 변경**

- 기존 사업자의 상점key → 새로운 사업자의 상점 key로 변경하는 작업입니다.
- 신규 유저의 유입이 적은 시간대로 신규 연동key로 전환이 필요하며, 신규 연동key로 내부적으로 충분한 테스트를 하신 후 진행해주셔야 합니다.
  - 포트원 관리자콘솔 >결제연동 > 새로운 상점정보를 채널등록

<Callout title="채널설정 방법 보러가기 ↗" icon="" />

##### **5. 사이트(앱서비스)에 구현된 코드 확인**

- 고객사 사이트에서 연동하시는 코드상에 상점정보 변경할 부분이 있는지 검토합니다. (개발담당자님 확인)

### **새로운 포트원 계정 사용**

<Callout content="기존 포트원 계정의 결제내역와 별개의 계정을 생성합니다." title="참고사항" icon="💡" />

**1.포트원 관리자콘솔 신규 회원가입**

- 포트원 관리자콘솔에서 새로운 계정으로 회원가입합니다.\
  한번도 사용된 적 없는 계정으로 가입을 해주시기 바랍니다.

##### **2. 사업자정보등록 & 신규 PG신청**

- 포트원 관리자콘솔 내 신규 사업자정보 등록하신 후 신규계약절차와 동일하게 전자결제신청을 접수합니다.

<Callout title="전자결제 신청가이드 보러가기 ↗" icon="" />

##### **3. 신규 사업자로 PG사와 신규계약진행**

- 신규 사업자 심사를 받기 위한 사이트 내에는 신규 사업자정보가 기입 되어있어야 하며, 카드사 심사를 받으실 상품페이지도 구현되어있어야 합니다. \
  (ex. 기존 서비스 유저들의 접근이 불가하도록 특정 계정으로만 로그인 가능하도록 처리)
- 신규 사이트에 연동하실 때는 새로운 포트원 관리자콘솔의 계정으로 연동이 되도록 유의하여 주시기 바랍니다.

**4. PG계약완료 후 상점정보 변경**

- 계약이 완료되면 포트원 관리자콘솔 새 계정에 신규 상점정보를 설정합니다.

<Callout title="실 운영환경 채널설정 방법 보러가기 ↗" icon="" />

##### **5. 사이트(앱서비스)에 구현된 코드 확인**

- 결제 테스트시 신규 사이트에서는 신규 발급된 상점아이디로, 신규 포트원 관리자콘솔 결제내역에 쌓이고 있는지 확인합니다.
